@@ -14,7 +14,7 @@ use HTML::Element 3.15 ();
 # this should be commented out in release versions....
 ##use Smart::Comments;
 
-our $VERSION = '2.14'; # VERSION
+our $VERSION = '2.16'; # VERSION
 our $AUTHORITY = 'cpan:NIGELM'; # AUTHORITY
 
 #
@@ -739,6 +739,7 @@ sub textflow {
         $self->blockquote_out( $_[0] );
     }
     else {
+        $_[0] = $self->_convert_spacelike_characters_to_space( $_[0] );
         for ( split( /(\s+)/, $_[0] ) ) {
             next unless length $_;
             $self->out($_);
@@ -783,6 +784,28 @@ sub pre_out   { confess "Must be overridden by subclass"; }
 sub adjust_lm { confess "Must be overridden by subclass"; }
 sub adjust_rm { confess "Must be overridden by subclass"; }
 
+# ------------------------------------------------------------------------
+# Supplied with a string in bytes, takes any characters that look like
+# they really should be spaces and turns them into spaces.
+# Currently only handles the following characters:
+# 0x00A0 NO-BREAK SPACE
+# 0x00AD SOFT HYPHEN.
+
+sub _convert_spacelike_characters_to_space {
+    my ( $self, $text ) = @_;
+
+    return if !defined $text;
+
+    eval {
+        require Encode;
+        my $unicode_text = Encode::decode( 'UTF-8', $text );
+        if ( $unicode_text =~ s/ ( \xA0 | \xAD ) / /gx ) {
+            $text = Encode::encode( 'UTF-8', $unicode_text );
+        }
+    };
+    return $text;
+}
+
 # ------------------------------------------------------------------------
 
 
@@ -792,12 +815,7 @@ __END__
 
 =pod
 
-=for test_synopsis 1;
-__END__
-
-=for stopwords formatters CPAN homepage
-
-=for HTML <a href="https://travis-ci.org/nigelm/html-formatter"><img src="https://travis-ci.org/nigelm/html-formatter.svg?branch=master"></a>
+=encoding UTF-8
 
 =head1 NAME
 
@@ -805,7 +823,14 @@ HTML::Formatter - Base class for HTML formatters
 
 =head1 VERSION
 
-version 2.14
+version 2.16
+
+=for test_synopsis 1;
+__END__
+
+=for stopwords dependancies formatters CPAN homepage
+
+=for HTML <a href="https://travis-ci.org/nigelm/html-formatter"><img src="https://travis-ci.org/nigelm/html-formatter.svg?branch=master"></a>
 
 =head1 SYNOPSIS
 
@@ -926,22 +951,24 @@ Format HTML into Rich Text Format
 Also the HTML manipulation libraries used - L<HTML::TreeBuilder>,
 L<HTML::Element> and L<HTML::Tree>
 
-=head1 INSTALLATION
+=for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
 
-See perlmodinstall for information and options on installing Perl modules.
+=head1 SUPPORT
 
-=head1 BUGS AND LIMITATIONS
+=head2 Bugs / Feature Requests
 
-You can make new bug reports, and view existing ones, through the
-web interface at L<http://rt.cpan.org/Public/Dist/Display.html?Name=HTML-Formatter>.
+Please report any bugs or feature requests through the issue tracker
+at L<http://rt.cpan.org/Public/Dist/Display.html?Name=HTML-Formatter>.
+You will be notified automatically of any progress on your issue.
 
-=head1 AVAILABILITY
+=head2 Source Code
 
-The project homepage is L<https://metacpan.org/release/HTML-Formatter>.
+This is open source software.  The code repository is available for
+public review and contribution under the terms of the license.
 
-The latest version of this module is available from the Comprehensive Perl
-Archive Network (CPAN). Visit L<http://www.perl.com/CPAN/> to find a CPAN
-site near you, or see L<https://metacpan.org/module/HTML::Formatter/>.
+L<https://github.com/nigelm/html-formatter>
+
+  git clone https://github.com/nigelm/html-formatter.git
 
 =head1 AUTHORS
 
@@ -963,7 +990,7 @@ Gisle Aas <gisle@ActiveState.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Nigel Metheringham, 2002-2005 Sean M Burke, 1999-2002 Gisle Aas.
+This software is copyright (c) 2016 by Nigel Metheringham, 2002-2005 Sean M Burke, 1999-2002 Gisle Aas.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
